pub type TfmFont<I, D, CS> = Ptr<TfmFontI<I, D, CS>>;Expand description
Aliased Type
pub struct TfmFont<I, D, CS> { /* private fields */ }Trait Implementations
Sourceimpl<I: TeXInt, D: TeXDimen + Numeric<I>, CS: CSName<u8>> Font for TfmFont<I, D, CS>
impl<I: TeXInt, D: TeXDimen + Numeric<I>, CS: CSName<u8>> Font for TfmFont<I, D, CS>
Sourcetype CS = CS
type CS = CS
The type of control sequences used to give a name to a font; returned by e.g.
\the when followed
by a font.Sourcefn has_char(&self, c: Self::Char) -> bool
fn has_char(&self, c: Self::Char) -> bool
Returns whether this font has a glyph for the given
Character.Sourcefn get_hyphenchar(&self) -> I
fn get_hyphenchar(&self) -> I
Returns the
\hyphenchar of this font.Sourcefn set_hyphenchar(&mut self, c: I)
fn set_hyphenchar(&mut self, c: I)
Sets the
\hyphenchar of this font.Sourcefn get_skewchar(&self) -> I
fn get_skewchar(&self) -> I
Returns the
\skewchar of this font.Sourcefn set_skewchar(&mut self, c: I)
fn set_skewchar(&mut self, c: I)
Sets the
\skewchar of this font.Sourcefn get_at(&self) -> Self::Dim
fn get_at(&self) -> Self::Dim
The size of the font; initially provided by the font itself, but can be set via e.g.
\font\foo=cmr10 at 12pt.Sourcefn has_at_set(&self) -> bool
fn has_at_set(&self) -> bool
Returns whether the size of the font has been set via e.g.
at ....Sourcefn get_dim(&self, idx: u16) -> Self::Dim
fn get_dim(&self, idx: u16) -> Self::Dim
Returns the
\fontdimen at the given index (-1); i.e. \fontdimen5 returns get_dim(4).Sourcefn set_dim(&mut self, idx: u16, d: Self::Dim)
fn set_dim(&mut self, idx: u16, d: Self::Dim)
Sets the
\fontdimen at the given index (-1); i.e. \fontdimen5=... calls set_dim(4).Sourcefn display<W: Write>(
&self,
_i: &<Self::CS as CSName<u8>>::Handler,
w: W,
) -> Result
fn display<W: Write>( &self, _i: &<Self::CS as CSName<u8>>::Handler, w: W, ) -> Result
Writes a human-readable representation of this font to the given
std::fmt::Writer Read moreSourcefn get_ic(&self, c: Self::Char) -> Self::Dim
fn get_ic(&self, c: Self::Char) -> Self::Dim
Returns the litalic correction of the given
Character in this font.Sourcefn set_ic(&mut self, c: Self::Char, d: Self::Dim)
fn set_ic(&mut self, c: Self::Char, d: Self::Dim)
Sets the litalic correction of the given
Character in this font.Sourcefn get_wd(&self, c: Self::Char) -> Self::Dim
fn get_wd(&self, c: Self::Char) -> Self::Dim
Returns the width the given
Character in this font.Sourcefn get_ht(&self, c: Self::Char) -> Self::Dim
fn get_ht(&self, c: Self::Char) -> Self::Dim
Returns the height the given
Character in this font.